//*****************************************************************************
// FILE: MD5Digest.cpp 
// DESC: Defines the entry point for the console application.
//
// By Giovanni Dicanio <giovanni.dicanio@gmail.com>
// 2008, September 27th
//*****************************************************************************


#include "stdafx.h"                 // Pre-compiled headers
#include "MD5FileCalculator.h"      // CMD5FileCalculator class


//-----------------------------------------------------------------------------
// MD5 Digest console app entry point.
// Usage: MD5Digest <filename>
//-----------------------------------------------------------------------------
int _tmain(int argc, _TCHAR* argv[])
{
    // Print info
    _tprintf( TEXT("\n*** MD5Digest Calculator ***\n\n") );
    _tprintf( TEXT("by Giovanni Dicanio <giovanni.dicanio@gmail.com>\n" ) );
    _tprintf( TEXT("(2008, September 27th)\n\n") );

    // Check command line
    if ( argc != 2 )
    {
        _tprintf( TEXT(">>> Bad command line; usage: MD5Digest <filename>\n") );
        exit( 1 );
    }

    // Extract file name from command line;
    // we are going to compute the MD5 digest of that file.
    CString filename = argv[1];

    // Init the MD5 file calculator
    CMD5FileCalculator md5calc( filename );

    // Check if initialization was OK
    if ( !md5calc.IsInitOK() )
    {
        _tprintf( TEXT(">>> Error in MD5 initialization.\n") );
        exit( 1 );
    }

    // MD5 Calculation loop
    _tprintf( TEXT("\nCalculating MD5 of file %s ...\n"), filename.GetString() );
    while ( md5calc.HashMore() )
    {
        // In this console application we just do nothing in the
        // body of this while loop.
        // In a GUI application this code could be put in a background
        // worker thread, and a progress bar could be updated with current
        // state of MD5 calculation.
    }

    // Check if MD5 computation was OK.
    if ( !md5calc.IsDigestReady() )
    {
        _tprintf( TEXT(">>> Error occurred during MD5 calculation.\n") );
        exit( 1 );
    }

    // All right: we can print the MD5 digest
    // (we print <MD5 digest> <filename>
    _tprintf( TEXT("\n%s  %s\n"), 
        md5calc.GetMD5Digest().GetString(),
        filename.GetString()
    );

    // All right
    return 0;
}

///////////////////////////////////////////////////////////////////////////////
